@@ -434,8 +434,8 @@ our %Modules = (
     },
 
     'experimental' => {
-        'DISTRIBUTION' => 'LEONT/experimental-0.035.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Thu May  1 06:44:57 2025',
+        'DISTRIBUTION' => 'LEONT/experimental-0.036.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sat Jul 19 12:50:08 2025',
         'FILES'        => q[cpan/experimental],
         'EXCLUDED'     => [qr{^xt/}],
     },
@@ -528,12 +528,13 @@ our %Modules = (
     },
 
     'ExtUtils::ParseXS' => {
-        'DISTRIBUTION' => 'LEONT/ExtUtils-ParseXS-3.57.tar.gz',
+        'DISTRIBUTION' => 'LEONT/ExtUtils-ParseXS-3.58.tar.gz',
         'FILES'        => q[dist/ExtUtils-ParseXS],
     },
 
     'File::Fetch' => {
-        'DISTRIBUTION' => 'BINGOS/File-Fetch-1.04.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/File-Fetch-1.08.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Thu May  1 07:12:12 2025',
         'FILES'        => q[cpan/File-Fetch],
     },
 
@@ -765,8 +766,8 @@ our %Modules = (
     },
 
     'Math::BigInt' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-2.005002.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Thu Apr 10 20:38:17 2025',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-2.005003.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sun Apr 13 14:50:24 2025',
         'FILES'        => q[cpan/Math-BigInt],
         'EXCLUDED'     => [
             qr{^xt/},
@@ -832,7 +833,7 @@ our %Modules = (
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250421.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250803.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -966,8 +967,8 @@ our %Modules = (
     },
 
     'Pod::Simple' => {
-        'DISTRIBUTION' => 'KHW/Pod-Simple-3.45.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Wed Aug  2 19:32:39 2023',
+        'DISTRIBUTION' => 'KHW/Pod-Simple-3.47.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Fri May 23 17:15:52 2025',
         'FILES'        => q[cpan/Pod-Simple],
         'EXCLUDED' => [
             qw{.ChangeLog.swp},
@@ -1008,17 +1009,9 @@ our %Modules = (
     },
 
     'Scalar::Util' => {
-        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.69.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Thu Apr 10 21:01:49 2025',
+        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.70.tar.gz',
+        'SYNCINFO'     => 'ether on Wed Jul 30 16:32:42 2025',
         'FILES'        => q[cpan/Scalar-List-Utils],
-        'CUSTOMIZED'   => [
-            'ListUtil.xs',
-            'lib/List/Util.pm',
-            'lib/List/Util/XS.pm',
-            'lib/Scalar/Util.pm',
-            'lib/Sub/Util.pm',
-            't/exotic_names.t'
-         ],
     },
 
     'Search::Dict' => {
@@ -1033,8 +1026,8 @@ our %Modules = (
     },
 
     'Socket' => {
-        'DISTRIBUTION' => 'PEVANS/Socket-2.038.tar.gz',
-        'SYNCINFO'     => 'LeoNerd on Sat Apr 27 09:57:02 2024',
+        'DISTRIBUTION' => 'PEVANS/Socket-2.040.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Wed Jul 16 09:34:44 2025',
         'FILES'        => q[cpan/Socket],
         'EXCLUDED'     => ['.editorconfig'],
     },
@@ -1109,8 +1102,8 @@ our %Modules = (
     },
 
     'Test::Harness' => {
-        'DISTRIBUTION' => 'LEONT/Test-Harness-3.50.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Wed Aug 14 21:59:59 2024',
+        'DISTRIBUTION' => 'LEONT/Test-Harness-3.52.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sun May  4 07:13:21 2025',
         'FILES'        => q[cpan/Test-Harness],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1126,8 +1119,8 @@ our %Modules = (
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302210.tar.gz',
-        'SYNCINFO'     => 'jkeenan on Tue Apr  1 20:47:53 2025',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302214.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Fri Jun 27 06:54:11 2025',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1147,7 +1140,7 @@ our %Modules = (
     },
 
     'Text::Balanced' => {
-        'DISTRIBUTION' => 'SHAY/Text-Balanced-2.06.tar.gz',
+        'DISTRIBUTION' => 'SHAY/Text-Balanced-2.07.tar.gz',
         'FILES'        => q[cpan/Text-Balanced],
     },
 
