@@ -859,9 +859,7 @@ int BZ_API(BZ2_bzDecompress) ( bz_stream *strm )
       }
    }
 
-   AssertH ( 0, 6001 );
-
-   return 0;  /*NOTREACHED*/
+    /*NOTREACHED*/
 }
 
 
