@@ -1,11 +1,9 @@
-
-require 5;
 package Pod::Simple::PullParserTextToken;
-use Pod::Simple::PullParserToken ();
 use strict;
-use vars qw(@ISA $VERSION);
-@ISA = ('Pod::Simple::PullParserToken');
-$VERSION = '3.42';
+use warnings;
+use Pod::Simple::PullParserToken ();
+our @ISA = ('Pod::Simple::PullParserToken');
+our $VERSION = '3.47';
 
 sub new {  # Class->new(text);
   my $class = shift;
@@ -98,7 +96,7 @@ pod-people-subscribe@perl.org to subscribe.
 
 This module is managed in an open GitHub repository,
 L<https://github.com/perl-pod/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/perl-pod/pod-simple.git> and send patches!
+to clone L<https://github.com/perl-pod/pod-simple.git> and send patches!
 
 Patches against Pod::Simple are welcome. Please send bug reports to
 <bug-pod-simple@rt.cpan.org>.
