@@ -17,20 +17,23 @@ our @EXPORT_OK = qw(
   dualvar isdual isvstring looks_like_number openhandle readonly set_prototype
   tainted
 );
-our $VERSION    = "1.63";
+our $VERSION    = "1.70";
 $VERSION =~ tr/_//d;
 
 require List::Util; # List::Util loads the XS
 List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
 
-# populating @EXPORT_FAIL is done in the XS code
-sub export_fail {
-  if (grep { /^isvstring$/ } @_ ) {
-    require Carp;
-    Carp::croak("Vstrings are not implemented in this version of perl");
-  }
+if( $] >= 5.040 ) {
+  # On Perl 5.40 and above, these builtins are stable, so we can use them
+  # instead of our own XS implementation
 
-  @_;
+  # Using this instead of a globref means we don't create an empty
+  # "builtins::" glob on older perls
+  no strict 'refs';
+  my $builtins = \%{"builtin::"};
+
+  *$_ = \&{ $builtins->{$_} } for (qw( blessed refaddr reftype weaken unweaken ));
+  *isweak = \&{ $builtins->{is_weak} };  # renamed
 }
 
 # set_prototype has been moved to Sub::Util with a different interface
