@@ -31,10 +31,10 @@
  * to work, but must NOT be retained in production code. */
 #ifndef PERL_SYS_TERM_BODY
 #  define PERL_SYS_TERM_BODY()                         \
-    ENV_TERM; USER_PROP_MUTEX_TERM; LOCALE_TERM;       \
-    HINTS_REFCNT_TERM; KEYWORD_PLUGIN_MUTEX_TERM;      \
-    OP_CHECK_MUTEX_TERM; OP_REFCNT_TERM;               \
-    PERLIO_TERM; MALLOC_TERM; 
+    SHUTDOWN_TERM; ENV_TERM; USER_PROP_MUTEX_TERM;      \
+    LOCALE_TERM;INTS_REFCNT_TERM;                      \
+    KEYWORD_PLUGIN_MUTEX_TERM;OP_CHECK_MUTEX_TERM;     \
+    OP_REFCNT_TERM;PERLIO_TERM; MALLOC_TERM;
 #endif
 #define dXSUB_SYS dNOOP
 
