@@ -1,11 +1,11 @@
 package Hash::Util::FieldHash;
 
-use 5.009004;
 use strict;
 use warnings;
-use Scalar::Util qw( reftype);
+no warnings 'experimental::builtin';
+use builtin qw(reftype);
 
-our $VERSION = '1.22';
+our $VERSION = '1.27';
 
 use Exporter 'import';
 our %EXPORT_TAGS = (
