@@ -5,32 +5,29 @@
 # Additions copyright 1996 by Charles Bailey.  Permission is granted
 # to distribute the revised code under the same terms as Perl itself.
 
-package File::Copy;
+package File::Copy 2.42;
+
+use v5.40;
+no warnings 'newline';
 
-use 5.035007;
-use strict;
-use warnings; no warnings 'newline';
-no warnings 'experimental::builtin';
-use builtin 'blessed';
 use overload;
 use File::Spec;
 use Config;
+use Exporter 'import';
+
 # We want HiRes stat and utime if available
 BEGIN { eval q{ use Time::HiRes qw( stat utime ) } };
-our(@ISA, @EXPORT, @EXPORT_OK, $VERSION, $Too_Big, $Syscopy_is_copy);
+
 sub copy;
 sub syscopy;
 sub cp;
 sub mv;
 
-$VERSION = '2.40';
+our @EXPORT = qw(copy move);
+our @EXPORT_OK = qw(cp mv);
 
-require Exporter;
-@ISA = qw(Exporter);
-@EXPORT = qw(copy move);
-@EXPORT_OK = qw(cp mv);
-
-$Too_Big = 1024 * 1024 * 2;
+our $Syscopy_is_copy;
+our $Too_Big = 1024 * 1024 * 2;
 
 sub croak {
     require Carp;
@@ -327,8 +324,6 @@ unless (defined &syscopy) {
     }
 }
 
-1;
-
 __END__
 
 =head1 NAME
@@ -395,9 +390,12 @@ You may use the syntax C<use File::Copy "cp"> to get at the C<cp>
 alias for this function. The syntax is I<exactly> the same.  The
 behavior is nearly the same as well: as of version 2.15, C<cp> will
 preserve the source file's permission bits like the shell utility
-C<cp(1)> would do, while C<copy> uses the default permissions for the
-target file (which may depend on the process' C<umask>, file
-ownership, inherited ACLs, etc.).  If an error occurs in setting
+C<cp(1)> would do with default options, while C<copy> uses the default
+permissions for the target file (which may depend on the process'
+C<umask>, file ownership, inherited ACLs, etc.).  That is, if the
+destination file already exists, C<cp> will leave its permissions
+unchanged; otherwise the permissions are taken from the source file
+and modified by the C<umask>.  If an error occurs in setting
 permissions, C<cp> will return 0, regardless of whether the file was
 successfully copied.
 
@@ -505,6 +503,3 @@ filesystem(s).
 
 File::Copy was written by Aaron Sherman I<E<lt>ajs@ajs.comE<gt>> in 1995,
 and updated by Charles Bailey I<E<lt>bailey@newman.upenn.eduE<gt>> in 1996.
-
-=cut
-
