@@ -72,7 +72,8 @@ PERL_STATIC_INLINE SV*
 Perl_new_sv(pTHX_ const char *file, int line, const char *func)
 {
     SV* sv;
-#ifndef DEBUG_LEAKING_SCALARS
+#if !defined(DEBUG_LEAKING_SCALARS) || \
+     (!defined(DEBUGGING) && !defined(PERL_MEM_LOG))
     PERL_UNUSED_ARG(file);
     PERL_UNUSED_ARG(line);
     PERL_UNUSED_ARG(func);
@@ -179,6 +180,14 @@ ALIGNED_TYPE(XPVOBJ);
         STRUCT_OFFSET(type, last_member) \
         + sizeof (((type*)SvANY((const SV *)0))->last_member)
 
+static const struct body_details fake_hv_with_aux =
+    /* The SVt_IV arena is used for (larger) PVHV bodies.  */
+    { sizeof(ALIGNED_TYPE_NAME(XPVHV_WITH_AUX)),
+      copy_length(XPVHV, xhv_max),
+      0,
+      SVt_PVHV, TRUE, NONV, HASARENA,
+      FIT_ARENA(0, sizeof(ALIGNED_TYPE_NAME(XPVHV_WITH_AUX))) };
+
 static const struct body_details bodies_by_type[] = {
     /* HEs use this offset for their arena.  */
     { 0, 0, 0, SVt_NULL, FALSE, NONV, NOARENA, 0 },
@@ -327,13 +336,11 @@ static const struct body_details bodies_by_type[] = {
 #ifndef PURIFY
 
 /* grab a new thing from the arena's free list, allocating more if necessary. */
-#define new_body_from_arena(xpv, root_index, type_meta) \
+#define new_body_from_arena(xpv, root_index) \
     STMT_START { \
         void ** const r3wt = &PL_body_roots[root_index]; \
         xpv = (PTR_TBL_ENT_t*) (*((void **)(r3wt))      \
-          ? *((void **)(r3wt)) : Perl_more_bodies(aTHX_ root_index, \
-                                             type_meta.body_size,\
-                                             type_meta.arena_size)); \
+          ? *((void **)(r3wt)) : Perl_more_bodies(aTHX_ root_index)); \
         *(r3wt) = *(void**)(xpv); \
     } STMT_END
 
@@ -341,7 +348,7 @@ PERL_STATIC_INLINE void *
 S_new_body(pTHX_ const svtype sv_type)
 {
     void *xpv;
-    new_body_from_arena(xpv, sv_type, bodies_by_type[sv_type]);
+    new_body_from_arena(xpv, sv_type);
     return xpv;
 }
 
@@ -350,14 +357,6 @@ S_new_body(pTHX_ const svtype sv_type)
 static const struct body_details fake_rv =
     { 0, 0, 0, SVt_IV, FALSE, NONV, NOARENA, 0 };
 
-static const struct body_details fake_hv_with_aux =
-    /* The SVt_IV arena is used for (larger) PVHV bodies.  */
-    { sizeof(ALIGNED_TYPE_NAME(XPVHV_WITH_AUX)),
-      copy_length(XPVHV, xhv_max),
-      0,
-      SVt_PVHV, TRUE, NONV, HASARENA,
-      FIT_ARENA(0, sizeof(ALIGNED_TYPE_NAME(XPVHV_WITH_AUX))) };
-
 /*
 =for apidoc newSV_type
 
