@@ -110,7 +110,7 @@ sub is_miniperl {
 }
 
 sub set_up_inc {
-    # Don’t clobber @INC under miniperl
+    # Don't clobber @INC under miniperl
     @INC = () unless is_miniperl;
     unshift @INC, @_;
 }
@@ -313,7 +313,8 @@ foreach my $x (split //, 'enrtfa\\\'"') {
 # Trying to avoid setting $_, or relying on local $_ to work.
 sub display {
     my @result;
-    foreach my $x (@_) {
+    foreach my $element (@_) {
+        my $x = $element; # Make a copy in case @_ contains unmodifiable elements
         if (defined $x and not ref $x) {
             my $y = '';
             foreach my $c (unpack($chars_template, $x)) {
